@@ -1,3 +1,4 @@
+from .attn import *
 from .fnet import *
 from .mixer import *
 from .vqgan import *
@@ -5,4 +6,5 @@ from .vanilla import *
 from .backbone import *
 from .protocol import *
 from .perceiver import *
+from .pool_former import *
 from .transformer import *
