@@ -2,22 +2,23 @@ from torch import Tensor
 from typing import Any
 from typing import Dict
 from typing import Optional
+from cftool.types import tensor_dict_type
 
-from .protocol import register_ml_module
-from .protocol import MixedStackedModel
-from ..bases import BAKEBase
-from ..bases import RDropoutBase
-from ...types import tensor_dict_type
+from ..bases import IBAKE
+from ..bases import IRDropout
+from ..register import register_ml_module
+from ..register import register_custom_loss_module
 from ...constants import LATENT_KEY
 from ...constants import PREDICTIONS_KEY
+from ..protocols.ml import MixedStackedModel
 
 
 @register_ml_module("mixer")
 class Mixer(MixedStackedModel):
     def __init__(
         self,
-        in_dim: int,
-        out_dim: int,
+        input_dim: int,
+        output_dim: int,
         num_history: int,
         latent_dim: int = 256,
         *,
@@ -26,8 +27,8 @@ class Mixer(MixedStackedModel):
         norm_type: Optional[str] = "batch_norm",
     ):
         super().__init__(
-            in_dim,
-            out_dim,
+            input_dim,
+            output_dim,
             num_history,
             latent_dim,
             token_mixing_type="mlp",
@@ -40,12 +41,12 @@ class Mixer(MixedStackedModel):
         )
 
 
-@register_ml_module("mixer_bake")
-class MixerWithBAKE(BAKEBase):
+@register_custom_loss_module("mixer_bake", is_ml=True)
+class MixerWithBAKE(IBAKE):
     def __init__(
         self,
-        in_dim: int,
-        out_dim: int,
+        input_dim: int,
+        output_dim: int,
         num_history: int,
         latent_dim: int = 256,
         *,
@@ -60,8 +61,8 @@ class MixerWithBAKE(BAKEBase):
     ):
         super().__init__()
         self.mixer = Mixer(
-            in_dim,
-            out_dim,
+            input_dim,
+            output_dim,
             num_history,
             latent_dim,
             num_layers=num_layers,
@@ -77,12 +78,12 @@ class MixerWithBAKE(BAKEBase):
         return {LATENT_KEY: latent, PREDICTIONS_KEY: net}
 
 
-@register_ml_module("mixer_r_dropout")
-class MixerWithRDropout(RDropoutBase):
+@register_custom_loss_module("mixer_r_dropout", is_ml=True)
+class MixerWithRDropout(IRDropout):
     def __init__(
         self,
-        in_dim: int,
-        out_dim: int,
+        input_dim: int,
+        output_dim: int,
         num_history: int,
         latent_dim: int = 256,
         *,
@@ -94,8 +95,8 @@ class MixerWithRDropout(RDropoutBase):
     ):
         super().__init__()
         self.mixer = Mixer(
-            in_dim,
-            out_dim,
+            input_dim,
+            output_dim,
             num_history,
             latent_dim,
             num_layers=num_layers,
